.. mfe_saw documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

McAfee SIEM API Wrapper (MFE_SAW)
=================================+

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage

User Guide:
    ESM
    Datasources
    Queries
    Watchlists
   
API R:
   
   ESM 
   DevTree
   DataSource 
   Query
   Watchlist


User Guide